#
# spec file for package python-traitlets
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-traitlets
Version:        5.11.2
Release:        1.1
Summary:        Traitlets Python configuration system
License:        BSD-3-Clause
URL:            https://github.com/ipython/traitlets
Source:         https://files.pythonhosted.org/packages/source/t/traitlets/traitlets-%{version}.tar.gz
Source99:       python-traitlets.rpmlintrc
BuildRequires:  %{python_module argcomplete >= 3.0.3}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 7}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
A configuration system for Python applications.

%prep
%autosetup -p1 -n traitlets-%{version}
sed -i 's/--color yes//' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%doc examples/
%license LICENSE
%{python_sitelib}/traitlets/
%{python_sitelib}/traitlets-%{version}*-info

%changelog
* Sat Oct  7 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.11.2
- Multiple typing upgrades and fix releases since 5.10.0
* Sun Sep 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.10.0
  * Added type hints to HasTraits.observe() and friends. #834
    (@scholer)
  * feat: trait typing #818 (@maartenbreddels)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Feb  2 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.9.0
  * Polishing argcomplete support #829 (@azjps)
* Sun Jan 15 2023 Ben Greiner <code@bnavigator.de>
- Update to 5.8.1
  * fix: mro_trait can be unbound when the class is not in mro #824
    (@maartenbreddels)
* Sun Dec 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.8.0
  * Shell command-line tab-completion via argcomplete #811 (@azjps)
  * Define trait.__doc__ = trait.help for better API Docs #816
    (@minrk)
  * Expose more attributes for typing #817 (@blink1073)
  * Fix lint #814 (@blink1073)
  * Additional Application examples and docs #811 (@azjps)
- Release 5.7.1
  * fix: some descriptors raise AttributeError #812
    (@maartenbreddels)
- Release 5.7.0
  * Performance: decrease runtime overhead for constructing
    HasTraits (up to 20x faster) #777 (@maartenbreddels)
  * Minor fixes for Application.aliases #810 (@azjps)
  * Adopt ruff and address lint #809 (@blink1073)
* Sat Oct 22 2022 Arun Persaud <arun@gmx.de>
- update to version 5.5.0:
  * Clean up application typing
  * Update tests and docs to use non-deprecated functions
  * Clean up version handling
  * Prep for jupyter releaser
  * Format the changelog
* Mon Sep 12 2022 Arun Persaud <arun@gmx.de>
- update to version 5.4.0:
  * Fix version_info
  * Make generated config files more lintable
  * Fix union trait from string
  * Add security.md, and tidelift bage
* Wed Jun 22 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.3.0
  * Fix traitlet name in docstring by @fcollonval in #745
  * Re-support multiple-alias key for ArgParseConfigLoader by
    @azjps in #687
- Drop traitlets-pr739-fixversion.patch
* Sun Jun  5 2022 Ben Greiner <code@bnavigator.de>
- Update to 5.2.2
  * Make all explicit and validate in test by @blink1073 in #737
  * Fix KeyError in Application.get_default_logging_config by
    @tonyroberts in #724
- Release 5.2.1
  * Switch to hatch backend by @blink1073 in #728
  * logging: don't attempt to close handlers unless they have been
    opened by @oliver-sanders in #727
- Release 5.2.0
  * Add mypy support by @blink1073 in #705
  * Disambiguate the use of the term value in the example. by
    @metaperl in #694
  * Correct spelling and grammar errors. by @metaperl in #695
  * DOC: Add log example by @Carreau in #693
  * Put description of signature_has_traits after the header for
    it. by @metaperl in #711
  * Application: add logging_config trait by @oliver-sanders in
    [#698]
  * [DOC] Give explicit list of private symbols for 5.0 by @vidartf
    in #692
  * Add pre-commit and run auto-formatters by @blink1073 in #699
  * Fix downstream test by @blink1073 in #701
  * Add docs on pre-commit and use manual hooks where appropriate
    by @blink1073 in #700
  * Set up flake8 by @blink1073 in #703
  * Typing: tell mypy we have type, update all. by @Carreau in #713
  * Improve CI by @blink1073 in #706
  * Fix typing errors by @blink1073 in #718
  * Use flit build backend by @blink1073 in #720
  * Add Changelog Entry for 5.2.0 by @blink1073 in #717
- Add traitlets-pr739-fixversion.patch -- gh#ipython/traitlets#739
* Sat Oct 30 2021 Ben Greiner <code@bnavigator.de>
- Update to version 5.1.1
  * 5.1.1 fixes compatibility issues with Python 3.10 (rc2).
- Release 5.1.0
  * Traitlets 5.1 brings a couple of updates and changes to
    traitlets, and is recommended for all users. What follow is a
    non-exhaustive list of changes:
  * Removal of the ``ipython_genutils`` dependency, this should
    remove any direct and indirect reliance on ``nose`` and prepare
    traitlets 5.1 for Python 3.10 and above compatibility, some
    test suite changes also accommodate Python 3.10 changes. If you
    package traitlets downstream, make sure to remove this
    dependency.
  * Removal of ``ipython_genutils`` may have change the default
    encoding detected for the command line argument parsing when
    not utf-8. We expect this to affect a small portion of older
    windows version. If you encounter issue let us know.
  * Stop recommendation of ``CUnicode`` in some circumstances as
    it's deprecated.
  * Our test suite is now using GitHub action instead of travis CI.
    If you are packaging downstream using the git repository, you
    may have to exclude the ``.github`` folder now, and can remove
    exclusion of
  * It fixes a parsing issue for list of one single element on the
    CLI.
  * We reserve the right to remove official support for Python 3.7
    in subsequent minor revisions.
- Releases 5.0.2 to 5.0.5
  * Support deprecated literals for sets, tuples on the
    command-line: ``nbconvert
  - -TagRemovePreprocessor.remove_cell_tags='  *"tag"}'``
  * Fix ``from_string_list`` for Tuples in general
  * Fix support for ``List(default_value=None, allow_none=True)``
    and other Container traits
  * Fix help output for nested aliases and tuple traits
  * Support deprecated use of byte-literals for bytes on the
    command-line: ``ipython kernel --Session.key="b'abc'"``. The
    `b` prefix is no longer needed in traitlets 5.0, but is
    supported for backward-compatibility
  * Improve output of configuration errors, especially when help
    output would make it hard to find the helpful error message
  * Fix regression in handling `--opt=None` on the CLI for configurable traits
    with `allow_none=True`
  * Fix casting bytes to unicode
- Traitlets 5.0
  * Traitlets 5.0 is a new version of traitlets that accumulate
    changes over a period of more close to four years; A number of
    internal refactoring made the internal code structure cleaner
    and simpler, and greatly improved the diagnostic error messages
    as well has help and documentation generation.
  * We expect no code change needed for any consumer of the Python
    API (ipywidgets, and alike), though CLI argument parsing have
    seen a complete rewrite, so if you have an application that
    does use the parsing logic of traitlets you may see changes in
    behavior, and now have access to more features.
  * Major changes are:
  - Removal of Python 2 support,
  - Removal of Python 3.0-3.6 support
  - we now follow NEP 29, and are thus Python 3.7+ only.
  - remove ``six`` as a dependency
  - remove ``funcsig`` as a dependency.
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to version 4.3.3
  * Adds Application.loaded_config_files property for accessing
    config files that have been loaded and makes the property
    idempotent on multiple loads.
* Wed Jul  5 2017 tbechtold@suse.com
- Add missing python-six BuildRequires
* Wed Jul  5 2017 tbechtold@suse.com
- Add missing python-six Requires
* Fri Apr 14 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3.2
  * using :meth:`_traitname_default()` without the ``@default``
    decorator is no longer deprecated.
  * Passing ``config=True`` in traitlets constructors is no longer
    deprecated.
- Update to 4.3.1
  * Compatibility fix for Python 3.6a1
  * Fix bug in Application.classes getting extra entries when
    multiple Applications are instantiated in the same process.
- Update to 4.3.0
  * Improve the generated config file output.
  * Allow TRAITLETS_APPLICATION_RAISE_CONFIG_FILE_ERROR env to
    override :attr:`Application.raise_config_file_errors`,
    so that config file errors can result in exiting immediately.
  * Avoid using root logger. If no application logger is registered,
    the ``'traitlets'`` logger will be used instead of the root
    logger.
  * Change/Validation arguments are now Bunch objects, allowing
    attribute-access, in addition to dictionary access.
  * Reduce number of common deprecation messages in certain cases.
  * Ensure command-line options always have higher priority than
    config files.
  * Add bounds on numeric traits.
  * Improves various error messages.
- Update to 4.2.2
  * Partially revert a change in 4.1 that prevented IPython's
    command-line options from taking priority over config files.
- Update to 4.2.1
  * Demotes warning about unused arguments in ``HasTraits.__init__``
    introduced in 4.2.0 to DeprecationWarning.
- Update to 4.2.0
  * :class:`JSONFileConfigLoader` can be used as a context manager
    for updating configuration.
  * If a value in config does not map onto a configurable trait,
    a message is displayed that the value will have no effect.
  * Unused arguments are passed to ``super()`` in
    ``HasTraits.__init__``, improving support for multiple
    inheritance.
  * Various bugfixes and improvements in the new API introduced
    in 4.1.
  * Application subclasses may specify
    ``raise_config_file_errors = True``
    to exit on failure to load config files,
    instead of the default of logging the failures.
- Update to 4.1
  * Decorators are used, rather than magic method names, for
    registering trait-related methods. See :doc:`using_traitlets`
    and :doc:`migration` for more info.
  * Deprecate ``Trait(config=True)`` in favor of
    ``Trait().tag(config=True)``. In general, metadata is added
    via ``tag`` instead of the constructor.
  * Trait attributes initialized with ``read_only=True`` can only
    be set with the ``set_trait`` method.
    Attempts to directly modify a read-only trait attribute raises
    a ``TraitError``.
  * The directional link now takes an optional `transform`
    attribute allowing the modification of the value.
  * Various fixes and improvements to config-file generation
    (fixed ordering, Undefined showing up, etc.)
  * Warn on unrecognized traits that aren't configurable, to avoid
    silently ignoring mistyped config.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to version
* Fri Aug 14 2015 toddrme2178@gmail.com
- Fix package naming consistency
* Thu Aug 13 2015 toddrme2178@gmail.com
- Update dependency names
* Tue Jul 21 2015 toddrme2178@gmail.com
- Initial version
